(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     37815,        869]
NotebookOptionsPosition[     34824,        819]
NotebookOutlinePosition[     35286,        837]
CellTagsIndexPosition[     35243,        834]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1168f77c-a0ae-45db-8546-951c8f40c226"],

Cell["Chapter 8, Section 8.8, Figure 8.9", "Section",
 CellChangeTimes->{{3.879407692064801*^9, 3.879407695244616*^9}, {
  3.879419472481398*^9, 
  3.879419472856743*^9}},ExpressionUUID->"6cac2bc5-b259-4d9a-930d-\
45403f355b0e"],

Cell[TextData[{
 "Use Eq.(8.135) to define a function ",
 StyleBox["xval", "Input"],
 " that returns the roots of the cubic to give the locations of the \
equilibrium points for given values of ",
 StyleBox["\[Delta]b", "Input"],
 " =  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Delta]", "_"], TraditionalForm]],ExpressionUUID->
  "969303fe-5e38-4afe-a2ba-74d9dc29131a"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f0a4628b-055e-4876-9de8-e3ba1e546bdf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xval", "[", "\[Delta]b_", "]"}], ":=", 
  RowBox[{"NRoots", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "3"}], "+", 
      RowBox[{"\[Delta]b", "*", "x"}], "-", "2"}], " ", "==", " ", "0"}], ",",
     " ", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879407331237639*^9, 3.879407331243308*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"479c2a17-adaa-4a20-9e87-bdaf25a0de06"],

Cell[TextData[{
 "We are interested in the location of the points of intersection for  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Delta]", "_"], TraditionalForm]],ExpressionUUID->
  "02c6223c-1ee4-45f3-bd8b-d3b677027e5e"],
 " = -3 and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Delta]", "_"], TraditionalForm]],ExpressionUUID->
  "7a242bf0-b1c6-4742-8fe8-3826422447c9"],
 " = 0."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.879407772524206*^9, 3.879407783458693*^9}, {
  3.879407973912632*^9, 3.8794080529625063`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"05800a02-ec85-4cb6-9989-4c50ba89be97"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol1", "=", 
  RowBox[{"x", "/.", 
   RowBox[{"{", 
    RowBox[{"ToRules", "[", 
     RowBox[{"xval", "[", 
      RowBox[{"-", "3"}], "]"}], "]"}], "}"}]}]}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"4e38fabb-c63f-4eea-8d55-3591d90c7d04"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.`"}], ",", 
   RowBox[{"-", "1.`"}], ",", "2.`"}], "}"}]], "Output",
 CellChangeTimes->{3.879407341714117*^9, 3.879407731420459*^9, 
  3.879408332378909*^9, 3.87941917432052*^9, 3.879419602705814*^9, 
  3.890986983360908*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"c9d684d2-9ae6-4eae-acc6-babce0c64348"]
}, Open  ]],

Cell[TextData[{
 "The double root at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = -1 corresponds to a bifurcation point between the stable and unstable \
branches."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.879407772524206*^9, 3.879407783458693*^9}, {
  3.879407973912632*^9, 3.8794080529625063`*^9}, {3.879408109122581*^9, 
  3.879408163918145*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cae51db1-740b-4ddc-a444-42f23aae27e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol2", "=", 
  RowBox[{"x", "/.", 
   RowBox[{"{", 
    RowBox[{"ToRules", "[", 
     RowBox[{"xval", "[", "0", "]"}], "]"}], "}"}]}]}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"86af4596-7932-4805-93d3-945ef53e7398"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.6299605249474366`"}], "-", 
    RowBox[{"1.0911236359717214`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.6299605249474366`"}], "+", 
    RowBox[{"1.0911236359717214`", " ", "\[ImaginaryI]"}]}], ",", 
   "1.2599210498948732`"}], "}"}]], "Output",
 CellChangeTimes->{3.879407349385809*^9, 3.8794077314522047`*^9, 
  3.879408332390362*^9, 3.879419174336142*^9, 3.8794196027297077`*^9, 
  3.890986983441265*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"0e101ace-e283-4992-b0fe-257f632b9b7a"]
}, Open  ]],

Cell[TextData[{
 "The single root at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 1.26992 corresponds to unstable equilibrium point."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.879407772524206*^9, 3.879407783458693*^9}, {
  3.879407973912632*^9, 3.8794080529625063`*^9}, {3.879408109122581*^9, 
  3.879408163918145*^9}, {3.879408211979137*^9, 3.879408232259039*^9}, {
  3.879408270329492*^9, 3.879408284924121*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c5368c9e-03f0-4b3f-88e6-1cb90bab90a5"],

Cell[TextData[{
 "Use Eq.(8.131) to define a function ",
 StyleBox["h1", "Input"],
 " that returns the value of the Hamiltonian for given values of ",
 StyleBox["x", "Input"],
 ", ",
 StyleBox["y", "Input"],
 " and ",
 StyleBox["\[Delta]b", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0851f859-286b-40ad-8252-26ed2589ddd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h1", "[", 
   RowBox[{"x_", ",", "y_", ",", "\[Delta]b_"}], "]"}], ":=", "\n", "   ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", "\[Delta]b", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], ")"}], "^", "2"}], "/", "4"}], "-", 
   RowBox[{"2", "*", "x"}]}]}]], "Input",
 CellChangeTimes->{{3.879407368843958*^9, 3.8794073688516827`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"dee836ee-5270-4806-a8b6-b533361153a3"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cce4d226-9d51-48a7-a5b5-cbcd2ae4b039"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"x\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"x\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
OverscriptBox[\"\[Delta]\", \"_\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\bar\\\\delta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"517476cb-315d-47fe-8a97-95f9dab9b7f7"],

Cell[TextData[{
 "Plot ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Delta]", "_"], TraditionalForm]],ExpressionUUID->
  "06b086fb-640c-44ca-abed-d60842a8d51a"],
 " as a function of ",
 StyleBox["x",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794075699941883`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7f635caa-5f46-40bd-b76a-82820d80d6c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "3"}], "-", "2"}], ")"}]}], "/", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15"}], ",", "15"}], "}"}]}], "}"}]}], ",", "\n", 
    "     ", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"AspectRatio", "->", "1"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"RotateLabel", "->", 
     RowBox[{"{", 
      RowBox[{"False", ",", "True"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"PlotPoints", "->", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879407419436173*^9, 3.8794074806251183`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"e503f049-5a9c-4bf1-9a6a-6c5dd8948172"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJw1l3k01V3UxxH63eu65pB5yHAJRaQeyVCeRKkkyUMDKlPKVJlKkkpCKUNR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       "]], LineBox[CompressedData["
1:eJwtlXs01Akfxsf9ljFEriOX133GrdiQvt9eW0iEVoSIkBYV6o0z1ZLtfVVs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       "]]},
     Annotation[#, "Charting`Private`Tag$3889#1"]& ], {}}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[OverscriptBox[\\\"\
\[Delta]\\\", \\\"_\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\
\" -> \\\"\\\\\\\\bar\\\\\\\\delta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"x\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-15., 15.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->{False, True},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.87940748534671*^9, 3.879407731734412*^9, 
  3.87940833266495*^9, 3.879419174488989*^9, 3.8794196028793364`*^9, 
  3.890986984211175*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"7973881b-b19f-40d9-961f-e07419104ae2"]
}, Open  ]],

Cell["Prepare the plot annotations.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"558f68b9-b66e-4868-abdc-5f2d768c8f6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circ1", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Circle", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sol1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"-", "3"}]}], "}"}], ",", 
        RowBox[{"0.02", "*", 
         RowBox[{"{", 
          RowBox[{"8", ",", "30"}], "}"}]}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"bba8cb4c-8c80-4d53-94c8-f94fd8ff7a38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circ2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Circle", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sol2", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", "0"}], "}"}], ",", 
        RowBox[{"0.02", "*", 
         RowBox[{"{", 
          RowBox[{"8", ",", "30"}], "}"}]}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"c867b099-0501-4051-b1a4-28614c747cc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dline", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", 
           RowBox[{"-", "3"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "3"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"1fcc4f28-a37a-4e1f-9db9-9042bda79dba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axes", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.004", "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "15"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "15"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.879407652585215*^9, 3.8794076548946238`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"c50ad024-24f1-44ca-ac84-2ab875eb44b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"abc", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<A\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.6", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<B\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", 
          RowBox[{"-", "10"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<C\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.2"}], ",", 
          RowBox[{"-", "8"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8794191635231953`*^9, 3.879419164527577*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"c3c15fed-a5a3-402f-a1fe-0ae4ab0c45b1"],

Cell["Combine the plot with the annotation.  This is Fig.8.9.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.879407625284734*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"825133e4-9617-4da1-8d42-3a2c7f47a9b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
  "pl", ",", "axes", ",", "dline", ",", "circ1", ",", "circ2", ",", "abc"}], 
  "]"}]], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"05622001-633f-44d0-9acb-b172cc907323"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJw1l3k01V3UxxH63eu65pB5yHAJRaQeyVCeRKkkyUMDKlPKVJlKkkpCKUNR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        "]], LineBox[CompressedData["
1:eJwtlXs01Akfxsf9ljFEriOX133GrdiQvt9eW0iEVoSIkBYV6o0z1ZLtfVVs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        "]]},
      Annotation[#, "Charting`Private`Tag$3889#1"]& ], {}}, {}}, 
   {Thickness[0.004], LineBox[{{0, -15}, {0, 15}}], 
    LineBox[{{-4, 0}, {4, 0}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-4, -3}, {4, -3}}]}, 
   {RGBColor[1, 0, 0], CircleBox[{-1., -3}, {0.16, 0.6}]}, 
   {RGBColor[1, 0, 0], CircleBox[{1.2599210498948732, 0}, {0.16, 0.6}]}, 
   StyleBox[{
     InsetBox["\<\"A\"\>", {0.6, 5}, NCache[
      ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
     InsetBox["\<\"B\"\>", {-0.6, -10}, NCache[
      ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]], 
     InsetBox["\<\"C\"\>", {-3.2, -8}, NCache[
      ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]]},
    FontFamily->"Times",
    FontSize->16]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[OverscriptBox[\\\"\
\[Delta]\\\", \\\"_\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\
\" -> \\\"\\\\\\\\bar\\\\\\\\delta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"x\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-15., 15.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->{False, True},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.879407547012583*^9, 3.879407731817417*^9, 
  3.879408332737834*^9, 3.879419174544654*^9, 3.8794196036378393`*^9, 
  3.890986984512945*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"73aecd56-7034-4116-a801-f3407bb2f9a4"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1048, 663},
WindowMargins->{{84, Automatic}, {Automatic, 23}},
TaggingRules-><|"TryRealOnly" -> False|>,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"68276d66-5ff7-4e9b-871f-79acb91c8b0a"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"1168f77c-a0ae-45db-8546-951c8f40c226"],
Cell[1000, 31, 228, 4, 67, "Section",ExpressionUUID->"6cac2bc5-b259-4d9a-930d-45403f355b0e"],
Cell[1231, 37, 504, 15, 50, "Text",ExpressionUUID->"f0a4628b-055e-4876-9de8-e3ba1e546bdf"],
Cell[1738, 54, 435, 11, 30, "Input",ExpressionUUID->"479c2a17-adaa-4a20-9e87-bdaf25a0de06"],
Cell[2176, 67, 630, 17, 54, "Text",ExpressionUUID->"05800a02-ec85-4cb6-9989-4c50ba89be97"],
Cell[CellGroupData[{
Cell[2831, 88, 270, 7, 30, "Input",ExpressionUUID->"4e38fabb-c63f-4eea-8d55-3591d90c7d04"],
Cell[3104, 97, 362, 8, 34, "Output",ExpressionUUID->"c9d684d2-9ae6-4eae-acc6-babce0c64348"]
}, Open  ]],
Cell[3481, 108, 454, 12, 53, "Text",ExpressionUUID->"cae51db1-740b-4ddc-a444-42f23aae27e1"],
Cell[CellGroupData[{
Cell[3960, 124, 248, 6, 30, "Input",ExpressionUUID->"86af4596-7932-4805-93d3-945ef53e7398"],
Cell[4211, 132, 579, 13, 34, "Output",ExpressionUUID->"0e101ace-e283-4992-b0fe-257f632b9b7a"]
}, Open  ]],
Cell[4805, 148, 518, 12, 53, "Text",ExpressionUUID->"c5368c9e-03f0-4b3f-88e6-1cb90bab90a5"],
Cell[5326, 162, 377, 13, 53, "Text",ExpressionUUID->"0851f859-286b-40ad-8252-26ed2589ddd3"],
Cell[5706, 177, 696, 20, 52, "Input",ExpressionUUID->"dee836ee-5270-4806-a8b6-b533361153a3"],
Cell[6405, 199, 656, 10, 53, "Text",ExpressionUUID->"cce4d226-9d51-48a7-a5b5-cbcd2ae4b039"],
Cell[7064, 211, 624, 11, 54, "Input",ExpressionUUID->"517476cb-315d-47fe-8a97-95f9dab9b7f7"],
Cell[7691, 224, 424, 14, 54, "Text",ExpressionUUID->"7f635caa-5f46-40bd-b76a-82820d80d6c8"],
Cell[CellGroupData[{
Cell[8140, 242, 1523, 42, 115, "Input",ExpressionUUID->"e503f049-5a9c-4bf1-9a6a-6c5dd8948172"],
Cell[9666, 286, 10003, 186, 379, "Output",ExpressionUUID->"7973881b-b19f-40d9-961f-e07419104ae2"]
}, Open  ]],
Cell[19684, 475, 225, 4, 53, "Text",ExpressionUUID->"558f68b9-b66e-4868-abdc-5f2d768c8f6c"],
Cell[19912, 481, 556, 17, 30, "Input",ExpressionUUID->"bba8cb4c-8c80-4d53-94c8-f94fd8ff7a38"],
Cell[20471, 500, 530, 16, 30, "Input",ExpressionUUID->"c867b099-0501-4051-b1a4-28614c747cc8"],
Cell[21004, 518, 540, 17, 30, "Input",ExpressionUUID->"1fcc4f28-a37a-4e1f-9db9-9042bda79dba"],
Cell[21547, 537, 845, 25, 30, "Input",ExpressionUUID->"c50ad024-24f1-44ca-ac84-2ab875eb44b9"],
Cell[22395, 564, 1217, 35, 52, "Input",ExpressionUUID->"c3c15fed-a5a3-402f-a1fe-0ae4ab0c45b1"],
Cell[23615, 601, 249, 4, 53, "Text",ExpressionUUID->"825133e4-9617-4da1-8d42-3a2c7f47a9b7"],
Cell[CellGroupData[{
Cell[23889, 609, 223, 5, 30, "Input",ExpressionUUID->"05622001-633f-44d0-9acb-b172cc907323"],
Cell[24115, 616, 10693, 200, 402, "Output",ExpressionUUID->"73aecd56-7034-4116-a801-f3407bb2f9a4"]
}, Open  ]]
}
]
*)

